---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

**Expected behavior**
A clear and concise description of what you expected to happen.

**Console logs**
If applicable, add logging information to help explain your problem.

**Versions:**
 - OS: [e.g. iOS]
 - Python-Version: [e.g. 3.9, 3.10]
 - Balder-Version:

**Additional context**
Add any other context about the problem here.
